==> jconf-0.1.zip: jconf-0.1/jconf.py <==
import json
import os
import sys


class Jconf(object):
    def __init__(self, path):
        self._path = path
        self._content = {}

        # Can we read this path
        if self.check_file(self._path):
            self.read()

    def read(self, path=''):
        # Custom path
        if not path:
            path = self._path

        with open(path, 'r') as file:
            self._raw_contents = file.read()

        self.json_to_dict()

    def json_to_dict(self):
        try:
            self._content = json.loads(self._raw_contents)
        except json.JSONDecodeError as e:
            print('Read Failed. Json decode error: {}'.format(e))


        for key, value in self._content.items():
            # Append leading '#' so num can be set as instance variable
            if key.isdigit():
                key = '#' + str(key)

            # Wizzardry Harry
            setattr(self, key, value)

    def write(self, path=''):
        # Custom path
        if not path:
            path = self._path

        for key, value in self.__dict__.items():
            if not key.startswith('_'):
                self._content[key] = value

        with open(path, 'w') as file:
            file.write(json.dumps(self._content))

    def dict_to_json(self):
        try:
            self._content = json.dumps(self._raw_contents)
        except json.JSONDecodeError as e:
            print('Json encode error:', e)

    @staticmethod
    def check_file(path):
        if os.path.exists(path):
            return True
        raise IOError('[!] File does not exist: {}'.format(path))

==> jconf-0.2.zip: jconf-0.2/jconf.py <==
import json
import os
import sys


class Jconf(object):
    def __init__(self, path):
        self._path = path
        self._content = {}

        # Can we read this path
        if self.check_file(self._path):
            self.read()

    def read(self, path=''):
        # Custom path
        if not path:
            path = self._path

        with open(path, 'r') as file:
            self._raw_contents = file.read()

        self.json_to_dict()

    def json_to_dict(self):
        try:
            self._content = json.loads(self._raw_contents)
        except json.JSONDecodeError as e:
            print('Read Failed. Json decode error: {}'.format(e))


        for key, value in self._content.items():
            # Append leading '#' so num can be set as instance variable
            if key.isdigit():
                key = '#' + str(key)

            # Wizzardry Harry
            setattr(self, key, value)

    def write(self, path=''):
        # Custom path
        if not path:
            path = self._path

        for key, value in self.__dict__.items():
            if not key.startswith('_'):
                self._content[key] = value

        with open(path, 'w') as file:
            file.write(json.dumps(self._content))

    def dict_to_json(self):
        try:
            self._content = json.dumps(self._raw_contents)
        except json.JSONDecodeError as e:
            print('Json encode error:', e)

    def is_empty(self):
        for key, value in self.__dict__.items():
            if not key.startswith('_'):
                print(key)
                return False
            return True


    @staticmethod
    def check_file(path):
        if os.path.exists(path):
            return True
        return False
